# Add auto-completion and a stored history file of commands to your Python
# interactive interpreter. Requires Python 2.0+, readline. Autocomplete is
# bound to the Esc key by default (you can change it - see readline docs).
#
# Store the file in ~/.pystartup, and set an environment variable to point
# to it:  "export PYTHONSTARTUP=/max/home/itamar/.pystartup" in bash.
#
# Note that PYTHONSTARTUP does *not* expand "~", so you have to put in the
# full path to your home directory.

import atexit
import os
import readline
import rlcompleter

# TODO(augie) I'd like to replace this with an environment variable
historyPath = os.path.expanduser("~/.python/python_history")

def save_history(historyPath=historyPath):
    import readline
    readline.write_history_file(historyPath)

if os.path.exists(historyPath):
    readline.read_history_file(historyPath)

atexit.register(save_history)

# Clean up after ourselves so we don't pollute the namespace
del os, atexit, readline, rlcompleter, save_history, historyPath
try:
    import IPython
    def ipy():
        IPython.Shell.start().mainloop()
except ImportError:
    pass
